@@ -18,7 +18,7 @@ from aesara.tensor.var import TensorVariable
 from aesara.updates import OrderedUpdates
 
 from aeppl.abstract import MeasurableVariable, _get_measurable_outputs
-from aeppl.joint_logprob import factorized_joint_logprob
+from aeppl.joint_logprob import conditional_logprob
 from aeppl.logprob import _logprob
 from aeppl.rewriting import (
     inc_subtensor_ops,
@@ -268,7 +268,7 @@ def logprob_ScanRV(op, values, *inputs, name=None, **kwargs):
         value_map: Dict[TensorVariable, TensorVariable]
     ) -> TensorVariable:
         """Create a log-likelihood inner-output for a `Scan`."""
-        logp_parts = factorized_joint_logprob(value_map, warn_missing_rvs=False)
+        logp_parts, _ = conditional_logprob(realized=value_map, warn_missing_rvs=False)
         return logp_parts.values()
 
     logp_scan_args = convert_outer_out_to_in(
@@ -513,7 +513,6 @@ measurable_ir_rewrites_db.register(
     # out2in(
     #     add_opts_to_inner_graphs, name="add_opts_to_inner_graphs", ignore_newtrees=True
     # ),
-    -100,
     "basic",
     "scan",
 )
@@ -521,11 +520,10 @@ measurable_ir_rewrites_db.register(
 measurable_ir_rewrites_db.register(
     "find_measurable_scans",
     find_measurable_scans,
-    0,
     "basic",
     "scan",
 )
 
 # Add scan canonicalizations that aren't in the canonicalization DB
-logprob_rewrites_db.register("scan_eqopt1", scan_eqopt1, -9, "basic", "scan")
-logprob_rewrites_db.register("scan_eqopt2", scan_eqopt2, -9, "basic", "scan")
+logprob_rewrites_db.register("scan_eqopt1", scan_eqopt1, "basic", "scan")
+logprob_rewrites_db.register("scan_eqopt2", scan_eqopt2, "basic", "scan")
